@@ -5,14 +5,18 @@
 #' `dataset2` is not a Crunch dataset, it will be uploaded as a new
 #' dataset before appending. If it is a CrunchDataset, it may be subsetted with
 #' a filter expression on the rows and a selection of variables on the columns.
-#' @param autorollback logical: If the append fails, revert the dataset back
-#' to its state before attempting to append? Default is \code{TRUE}, and you
-#' probably won't want to change that.
+#' @param autorollback Deprecated. This option no longer does anything.
 #' @return `dataset1`, updated with `dataset2`, potentially filtered on rows and
 #' variables, appended to it.
 #' @export
-appendDataset <- function (dataset1, dataset2, autorollback=TRUE) {
+appendDataset <- function (dataset1, dataset2, autorollback) {
     stopifnot(is.dataset(dataset1))
+
+    if (!missing(autorollback)) {
+        warning("The ", sQuote("autorollback"),
+                " argument is deprecated and has no effect", call.=FALSE)
+    }
+
     if (!is.dataset(dataset2)) {
         temp.ds.name <- paste("Appending to", name(dataset1), now())
         message("Creating ", dQuote(temp.ds.name), " as temporary dataset")
@@ -35,8 +39,8 @@ appendDataset <- function (dataset1, dataset2, autorollback=TRUE) {
     ## Preventatively, delete the primary key on dataset1 so that this appends
     ## and not "upsert"
     pk(dataset1) <- NULL
-    
+
     ## POST the batch. This will error with a useful message if it fails
-    dataset1 <- addBatch(dataset1, body=payload, autorollback=autorollback)
+    dataset1 <- addBatch(dataset1, body=payload)
     invisible(dataset1)
 }
