@@ -16,15 +16,15 @@
 #' @name crunch
 NULL
 
-#' @importFrom httr set_config
-.onAttach <- function (lib, pkgname="crunch") {
+#' @importFrom httr config add_headers
+.onLoad <- function (lib, pkgname="crunch") {
     setIfNotAlready(
         crunch.api="https://app.crunch.io/api/",
         httpcache.on=TRUE,
         crunch.namekey.dataset="alias",
         crunch.namekey.array="alias"
     )
-    set_config(crunchConfig())
+    set_crunch_config()
     notifyIfNewVersion()
     invisible()
 }
