@@ -1,4 +1,20 @@
 .updateVariable <- function (variable, value, filter=NULL) {
+    ## if the value is an expression, check that the value is not a derivation,
+    ## those can be dangerous if they change the variable type.
+    ## only needed until https://www.pivotaltracker.com/story/show/154982045 is
+    ## resolved
+    if (is.Expr(value)) {
+        castFuncs <- c("cast", "format_datetime", "parse_datetime",
+                       "numeric_to_datetime", "datetime_to_numeric")
+
+        if (has.function(value@expression, castFuncs)) {
+            halt("A variable cannot be updated with a derivation that changes ",
+                 "its type. Are you trying to overwrite a variable with a ",
+                 "derivation of itself to change the type? If so, you might ",
+                 "want to use `type(ds$variable)<-` instead.")
+        }
+    }
+
     ## Construct a ZCL update payload, then POST it
     payload <- list(command="update",
         variables=.updatePayload(variable, value))
@@ -37,13 +53,16 @@
 
 .dispatchFilter <- function (f) {
     ## Given a valid R index (numeric, logical) or CrunchExp, make a ZCL (?) filter
+    ## TODO: f <- zcl(f) ?
     if (is.logical(f)) {
-        ## Validate
+        ## TODO: Validate
+        ## TODO: send 0/1
+        # f <- as.integer(f)
+        # And what about NA? set as 0? set to -1? let downstream set to -1?
         f <- which(f)
-    }
+    } # TODO: if 0/1, else if
     if (is.numeric(f)) {
-        ## Validate
-
+        ## TODO: Validate
         f <- .seqCrunch(zfunc("row"), f - 1)
     }
     return(f)
@@ -205,7 +224,7 @@ setMethod("[<-", c("CrunchVariable", "ANY", "missing", "logical"),
             return(x)
         } else if (has.categories(x) &&
             all(names(categories(x)) %in% c("True", "False", "No Data"))) {
-
+            ## TODO: next, make this more 3VL-aware
             ## This is "logical-as-categorical", so we can take TRUE/FALSE values
             value <- c("True", "False")[2L - as.integer(value)]
             return(.categorical.update[["character"]](x, i, j, value))
