@@ -12,16 +12,16 @@ with_test_authentication({
             expect_true("CA" %in% names(part2))
             expect_true(is.CA(part1$CA))
             expect_true(is.Numeric(part2$CA))
-            expect_output(batches(part1),
+            expect_prints(batches(part1),
                 get_output(data.frame(id=c(0, 1),
                 status=c("imported", "imported"))))
         })
         test_that("compareDatasets catches that", {
             comp <- compareDatasets(part1, part2)
-            expect_output(summary(comp), "Type mismatch: 1")
+            expect_prints(summary(comp), "Type mismatch: 1")
         })
         test_that("If the append fails and reports conflict, and the batch is backed out", {
-            expect_output(batches(part1),
+            expect_prints(batches(part1),
                 get_output(data.frame(id=c(0, 1),
                 status=c("imported", "imported"))))
 
@@ -31,7 +31,7 @@ with_test_authentication({
                 NA) ## No Result URL printed because autorollback=TRUE
 
             part1 <- refresh(part1)
-            expect_output(batches(part1),
+            expect_prints(batches(part1),
                 get_output(data.frame(id=c(0, 1),
                 status=c("imported", "imported"))))
         })
@@ -44,7 +44,7 @@ with_test_authentication({
         part2 <- newDataset(d2)
         test_that("compareDatasets catches that", {
             comp <- compareDatasets(part1, part2)
-            expect_output(summary(comp), "Type mismatch: 1")
+            expect_prints(summary(comp), "Type mismatch: 1")
         })
         test_that("Append detects text/numeric type mismatch", {
             expect_error(appendDataset(part1, part2),
