@@ -6,31 +6,47 @@ with_mock_crunch({
 
     test_that("conditionalTransform input validation", {
         expect_error(conditionalTransform("gender", data = ds),
-                     'no conditions have been supplied; please supply formulas as conditions.')
+                     paste0("Conditions must be supplied: Have you forgotten ",
+                            "to supply conditions as formulas in either the",
+                            " .*formulas.* argument, or through .*....*"))
         expect_error(conditionalTransform("bar" ~ "foo", data = ds),
-                     'The left-hand side provided is not a CrunchLogicalExpr: "bar"')
+                     "The left-hand side provided must be a CrunchLogicalExpr: .*bar.*")
 
         expect_error(conditionalTransform(gender ~ "foo", data = ds, type="unknown"),
-                     paste0("type must be either ", dQuote("categorical"), ", ",
+                     paste0("Type must be either ", dQuote("categorical"), ", ",
                             dQuote("text"), ", or ", dQuote("numeric")))
 
         expect_warning(conditionalTransform(gender == 'Male' ~ "foo", data = ds, type="text",
                                           categories=c("foo", "bar")),
-                     paste0("type is not ", dQuote("categorical"), " ignoring ",
+                     paste0("Type is not ", dQuote("categorical"), " ignoring ",
                      dQuote("categories")))
         # check that we can't reference two different datasets
         expect_error(conditionalTransform(ds$gender == 'Male' ~ "foo",
                                           ds2$gender == 'Male' ~ "foo",
                                           name = "new"),
-                     paste0("There is more than one dataset referenced. Please ",
-                            "supply only one."))
+                     paste0("There must be only one dataset referenced. Did ",
+                            "you accidentally supply more than one?"))
 
         # updated to use a categorical variable as the source
         expect_error(conditionalTransform(gender == "Male" ~ textVar,
                                           data = ds,
                                           type="categorical",
                                           categories = c("l", "m", "s", "h", "z")),
-                     "there were categories in the results \\(x\\) that were not specified in categories")
+                     paste0("When specifying categories, all categories in the",
+                            " results must be included. These categories are ",
+                            "in the results that were not specified in ",
+                            "categories: x"))
+
+        # we can't provide conditions in both ... and formulas
+        expect_error(conditionalTransform(gender == "Male" ~ textVar,
+                                          data = ds,
+                                          type="categorical",
+                                          categories = c("l", "m", "s", "h", "z"),
+                                          formulas = list(
+                                              gender == "Male" ~ textVar
+                                          )),
+                     paste0("Must not supply conditions in both the ",
+                            ".*formulas.* argument and .*....*"))
     })
 
     test_that("conditionalTransform works with categories", {
@@ -42,6 +58,17 @@ with_mock_crunch({
                                        6, 3, -1, 5))
         expect_equal(new_var$type, "categorical")
 
+        # and we can use the formulas arg
+        expect_silent(new_var <- conditionalTransform(data = ds,
+                                                      type = "categorical",
+                                                      formulas = list(
+                                                          gender == "Male" ~ textVar
+                                                      )))
+        expect_equal(new_var$values, c(-1, -1, -1, -1, -1, -1, 2, -1, -1, -1,
+                                       3, -1, 4, -1, -1, -1, -1, -1, -1, -1, 1,
+                                       6, 3, -1, 5))
+        expect_equal(new_var$type, "categorical")
+
         expect_silent(new_var <- conditionalTransform(ds$gender == "Male" ~ ds$textVar,
                                                       type = "categorical"))
         expect_equal(new_var$values, c(-1, -1, -1, -1, -1, -1, 2, -1, -1, -1,
@@ -123,7 +150,7 @@ with_mock_crunch({
         expect_warning(new_var <- conditionalTransform(gender == "Male" ~ textVar,
                                                       data = ds,
                                                       categories = textVarCats),
-                       paste0("type is not ", dQuote("categorical"),
+                       paste0("Type is not ", dQuote("categorical"),
                               " ignoring ", dQuote("categories")))
         expect_equal(new_var$values, c(NA, NA, NA, NA, NA, NA, "l", NA, NA, NA, "m",
                                        NA, "s", NA, NA, NA, NA, NA, NA, NA, "h", "z",
@@ -267,6 +294,17 @@ with_test_authentication({
                                    "2", "2", "2", "other", "3", "Belgium", "6", "Fluffy",
                                    "other", "Austria", "other", "2"))
     })
+    test_that("conditionalTransform with else_condition and formula lsit", {
+        ds$new1_again <- conditionalTransform(data = ds, else_condition = "other",
+                                        formulas = list(
+                                            ndogs < 1 ~ country,
+                                            ndogs == 1 ~ q3,
+                                            ndogs > 1 ~ ndogs
+                                        ))
+        expect_equal(as.vector(ds$new1_again), c("Jasmine", "other", "2", "3", "Zeus", "2", "2", "3",
+                                           "2", "2", "2", "other", "3", "Belgium", "6", "Fluffy",
+                                           "other", "Austria", "other", "2"))
+    })
     test_that("conditionalTransform with text", {
         ds$new2 <- conditionalTransform(ndogs < 1 ~ country,
                                     ndogs == 1 ~ q3,
@@ -362,7 +400,6 @@ with_test_authentication({
     })
 
     test_that("conditionalTransform with an exclusion set with a text varaible", {
-        skip("Will fail until bug https://www.pivotaltracker.com/story/show/152700750 is fixed")
         exclusion(ds) <- ds$ndogs > 2
         ds$new10 <- conditionalTransform(ndogs < 1 ~ "lonely",
                                         ndogs == 1 ~ q3,
