@@ -4,7 +4,7 @@ with_mock_crunch({
     ## Load a ton of cube fixtures via the tab book feature
     ds <- loadDataset("test ds")
     m <- multitables(ds)[[1]]
-    with_POST("https://app.crunch.io/api/datasets/1/multitables/apidocs-tabbook/", {
+    with_POST("https://app.crunch.io/api/datasets/1/multitables/apidocs-as_selected-tabbook/", {
         book <- tabBook(m, data=ds)
     })
     cube <- book[[2]][[2]]
@@ -16,7 +16,7 @@ with_mock_crunch({
         expect_identical(dimnames(d),
             list(
                 q1=c("Cat", "Dog", "Bird", "Skipped", "Not Asked"),
-                allpets=c("Cat", "Dog", "Bird", "<NA>", "<NA>", "<NA>")
+                allpets=c("Cat", "Dog", "Bird")
             ))
         expect_identical(names(dimnames(d)), c("q1", "allpets"))
     })
@@ -38,13 +38,13 @@ with_mock_crunch({
         expect_identical(types(cube),
             c("categorical", "subvariable_items"))
         expect_identical(notes(cube),
-            c(NA_character_, NA_character_))
+            c("", ""))
     })
     test_that("Getting those attributes from MultitableResult (the column variables)", {
         expect_identical(names(book[[1]]), c("Total", "All pets owned", "Pet"))
         expect_identical(aliases(book[[1]]), c("total", "allpets", "q1"))
         expect_identical(descriptions(book[[1]]),
-            c(NA,
+            c("",
             "Do you have any of these animals as pets? Please select all that apply.",
             "What is your favorite pet?"))
     })
@@ -55,7 +55,22 @@ with_mock_crunch({
         expect_identical(descriptions(book)[2:4],
             c("What is your favorite pet?",
             "Name the kinds of pets you have at these locations.",
-            NA))
+            ""))
+    })
+
+    test_that("subvariable/subrefrence methods", {
+        catarray_x_mr <- loadCube(test_path("cubes/catarray-x-mr.json"))
+        cat_array_var <- variables(catarray_x_mr)[[1]]
+        expect_equal(aliases(subvariables(cat_array_var)),
+                     c("cat_feeling", "dog_feeling"))
+        expect_equal(names(subvariables(cat_array_var)),
+                     c("cat_feeling", "dog_feeling"))
+
+        mr_var <- variables(catarray_x_mr)[[3]]
+        expect_equal(aliases(subvariables(mr_var)),
+                     c("food_opinion#", "rest_opinion#", "play_opinion#"))
+        expect_equal(names(subvariables(mr_var)),
+                     c("food_opinion", "rest_opinion", "play_opinion"))
     })
 
     test_that("'measures' metadata", {
@@ -81,3 +96,19 @@ with_mock_crunch({
             c("Gender", "Text variable ftw", "Interview Start Time", "Birth Year"))
     })
 })
+
+with_test_authentication({
+    ds <- newDataset(data.frame(x=c(LETTERS[1:10])), name = 'test for notes')
+
+    test_that("empty variable description are empty string", {
+        expect_equal(description(ds$x), "")
+        expect_equal(notes(ds$x), "")
+    })
+
+    test_that("empty variable description are empty string in a cube too", {
+        cube <- crtabs(~ x, ds)
+        expect_equal(descriptions(variables(cube)), description(ds$x))
+        expect_equal(notes(variables(cube)), notes(ds$x))
+    })
+
+})
