@@ -141,8 +141,47 @@ printed_order_apidocs2 <- c(
     "[+] Dimensions",
     "    Country",
     "    Wave",
+    "Person ID",
     "Weight",
-    "Person ID"
+    "Case ID"
+)
+
+printed_order_apidocs2_merge_by_stringid <- c(
+    "    [+] Key Pet Indicators",
+    "        All pets owned",
+    "        Pet",
+    "        Pets by location",
+    "    [+] Dog Metrics",
+    "        Number of dogs",
+    "        [+] Number of dogs by type",
+    "            Number of dogs -- With papers",
+    "            Number of dogs -- Mutts",
+    "    [+] Details",
+    "        Pet name",
+    "    [+] Dimensions",
+    "        Country",
+    "        Wave",
+    "Weight",
+    "Case ID"
+)
+
+printed_order_apidocs2_merge_by_caseid <- c(
+    "    [+] Key Pet Indicators",
+    "        All pets owned",
+    "        Pet",
+    "        Pets by location",
+    "    [+] Dog Metrics",
+    "        Number of dogs",
+    "        [+] Number of dogs by type",
+    "            Number of dogs -- With papers",
+    "            Number of dogs -- Mutts",
+    "    [+] Details",
+    "        Pet name",
+    "    [+] Dimensions",
+    "        Country",
+    "        Wave",
+    "    Person ID",
+    "Weight"
 )
 
 with_test_authentication({
@@ -150,7 +189,7 @@ with_test_authentication({
     with_consent(ds1$allpets_1 <- NULL)
     ds2 <- newDatasetFromFixture("apidocs2")
     test_that("Shape of apidocs2", {
-        expect_output(ordering(ds2),
+        expect_prints(ordering(ds2),
             paste(printed_order_apidocs2, collapse="\n"), fixed=TRUE)
         expect_identical(names(ds2), c("allpets", "q1", "petloc", "ndogs",
             "ndogs_a", "ndogs_b", "q3", "country", "wave", "stringid"))
@@ -165,15 +204,13 @@ with_test_authentication({
         ds1 <- merge(ds1, ds2, by.x=ds1$id, by.y=ds2$stringid)
         expect_is(ds1, "CrunchDataset")
         expect_identical(dim(ds1), c(14L, 12L))
-        expect_output(ordering(ds1),
+        expect_prints(ordering(ds1),
             paste(c(
                 "ID",
                 "Join matches",
                 "Another variable",
                 paste0("[+] ", name(ds2)),
-                paste("    ",
-                    printed_order_apidocs2[-length(printed_order_apidocs2)],
-                    sep="", collapse="\n")),
+                paste0(printed_order_apidocs2_merge_by_stringid)),
                 collapse="\n"),
             fixed=TRUE)
         expect_identical(names(ds1),
@@ -196,15 +233,13 @@ with_test_authentication({
             "Variable caseid is hidden")
         expect_is(ds1, "CrunchDataset")
         expect_identical(dim(ds1), c(14L, 13L))
-        expect_output(ordering(ds1),
+        expect_prints(ordering(ds1),
             paste(c(
                 "ID",
                 "Join matches",
                 "Another variable",
                 paste0("[+] ", name(ds2)),
-                paste("    ",
-                    printed_order_apidocs2,
-                    sep="", collapse="\n")),
+                paste0(printed_order_apidocs2_merge_by_caseid)),
                 collapse="\n"),
             fixed=TRUE)
         expect_identical(names(ds1),
@@ -232,7 +267,7 @@ with_test_authentication({
         with_consent(ds1$allpets_1 <- NULL)
         ds1 <- merge(ds1, ds2[ds2$stringid == "43805958", c("stringid", "q1", "petloc")],
             by.x="id", by.y="stringid")
-        expect_output(ordering(ds1),
+        expect_prints(ordering(ds1),
                       paste(c(
                           "ID",
                           "Join matches",
@@ -269,34 +304,15 @@ with_test_authentication({
         with_consent(ds1$allpets_1 <- NULL)
         ds1 <- merge(ds1, ds2[ds2$stringid == "43805958",],
             by.x="id", by.y="stringid")
-        expect_output(ordering(ds1),
-                      paste(c(
-                          "ID",
-                          "Join matches",
-                          "Another variable",
-                          paste0("[+] ", name(ds2)),
-                          paste("    ",
-                                c(
-                                    "[+] Key Pet Indicators",
-                                    "    All pets owned",
-                                    "    Pet",
-                                    "    Pets by location",
-                                    "[+] Dog Metrics",
-                                    "    Number of dogs",
-                                    "    [+] Number of dogs by type",
-                                    "        Number of dogs -- With papers",
-                                    "        Number of dogs -- Mutts",
-                                    "[+] Details",
-                                    "    Pet name",
-                                    "[+] Dimensions",
-                                    "    Country",
-                                    "    Wave",
-                                    "Weight",
-                                    "Case ID"
-                                ),
-                                sep="", collapse="\n")),
-                          collapse="\n"),
-                      fixed=TRUE)
+        expect_prints(ordering(ds1),
+            paste(c(
+                "ID",
+                "Join matches",
+                "Another variable",
+                paste0("[+] ", name(ds2)),
+                paste0(printed_order_apidocs2_merge_by_stringid)),
+                collapse="\n"),
+            fixed=TRUE)
         expect_identical(names(ds1),
             c("id", "matches", "other_var", "allpets", "q1", "petloc", "ndogs",
             "ndogs_a", "ndogs_b", "q3", "country", "wave"))
