@@ -1,6 +1,17 @@
 context("Polling progress")
 
+test_that("progressMessage", {
+    with(temp.option(crunch.show.progress=FALSE), {
+        expect_silent(progressMessage("Message!"))
+    })
+    with(temp.option(crunch.show.progress=NULL), {
+        expect_message(progressMessage("Message!"), "Message!")
+    })
+})
+
 with_mock_crunch({
+    options(crunch.show.progress=NULL)
+    on.exit(options(crunch.show.progress=FALSE))
     test_that("If progress polling gives up, it tells you what to do", {
         with(temp.option(crunch.timeout=0.0005), {
             expect_error(
@@ -8,7 +19,7 @@ with_mock_crunch({
                     "|================"),
                 paste('Your process is still running on the server. It is',
                     'currently 23% complete. Check',
-                    '`httpcache::uncached(crGET("https://app.crunch.io/api/progress/1/"))`',
+                    '`pollProgress("https://app.crunch.io/api/progress/1/")`',
                     'until it reports 100% complete'),
                 fixed=TRUE)
         })
@@ -33,7 +44,7 @@ with_mock_crunch({
             url <- build_mock_url(paste0(url, counter)) ## Add counter
             counter <<- counter + 1 ## Increment
             return(fake_response(url, "GET",
-                content=readBin(url, "raw", 4096), ## Assumes mock is under 4K
+                content=readBin(find_mock_file(url), "raw", 4096), ## Assumes mock is under 4K
                 status_code=200, headers=list(`Content-Type`="application/json")))
         },
         test_that("Progress polling goes until 100 and has a newline", {
@@ -47,6 +58,17 @@ with_mock_crunch({
             expect_match(out[1], "=| 100%", fixed=TRUE)
             expect_match(out[2], "command on next line", fixed=TRUE)
         }),
+        test_that("Progress polling goes until 100 when silent", {
+            counter <<- 1
+            with(temp.option(crunch.show.progress=FALSE), {
+                expect_silent(
+                    expect_equal(pollProgress("https://app.crunch.io/api/progress/",
+                                              wait=.001),
+                        100
+                    )
+                )
+            })
+        }),
         test_that("Auto-polling with a progress resource", {
             counter <<- 1
             logfile <- tempfile()
@@ -58,17 +80,8 @@ with_mock_crunch({
             })
             logs <- loadLogfile(logfile)
             expect_identical(logs$verb, c("GET", "GET"))
-            expect_identical(logs$url,
-                c("app.crunch.io/api/progress/1.json", "app.crunch.io/api/progress/2.json"))
-        }),
-        test_that("Progress silencing in tests", {
-            counter <<- 1
-            expect_silent(
-                with_silent_progress(
-                    expect_identical(handleAPIresponse(fakeProg("https://app.crunch.io/api/progress/")),
-                        "https://app.crunch.io/api/datasets/")
-                )
-            )
+            expect_identical(sub("\\.json$", "", logs$url),
+                c("app.crunch.io/api/progress/1", "app.crunch.io/api/progress/2"))
         }),
         test_that("Auto-polling when progress reports failure", {
             counter <<- 1
@@ -83,8 +96,8 @@ with_mock_crunch({
             })
             logs <- loadLogfile(logfile)
             expect_identical(logs$verb, c("GET", "GET"))
-            expect_identical(logs$url,
-                c("app.crunch.io/api/progress2/1.json", "app.crunch.io/api/progress2/2.json"))
+            expect_identical(sub("\\.json$", "", logs$url),
+                c("app.crunch.io/api/progress2/1", "app.crunch.io/api/progress2/2"))
         })
     )
 })
