@@ -1,6 +1,6 @@
 context("Sessions")
 
-with_mock_HTTP({
+with_mock_crunch({
     cr <- session()
     test_that("session() returns a session object", {
         expect_is(cr$datasets, "DatasetCatalog")
